@@ -1,7 +1,7 @@
 package Log::Any::DBI::Query;
 
-our $DATE = '2015-08-17'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-01-23'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -11,14 +11,27 @@ use Log::Any::IfLOG '$log';
 use DBI;
 use Log::Any::For::Class qw(add_logging_to_class);
 
+my $log_query  = $ENV{LOG_SQL_QUERY}  // 1;
+my $log_result = $ENV{LOG_SQL_RESULT} // 0;
+
 sub _precall_logger {
     my $args = shift;
     my $margs = $args->{args};
 
-    $log->tracef("SQL query: {{%s}}", $margs->[1]);
+    my ($meth) = $args->{name} =~ /.+::(.+)/;
+    return if $meth =~ /\Afetch.+\z/;
+    $log->tracef("SQL query (%s): {{%s}}", $meth, $margs->[1]);
 }
 
-sub _postcall_logger {}
+sub _postcall_logger {
+    my $args = shift;
+
+    $log->tracef("D1: %s", $args->{name});
+
+    my ($meth) = $args->{name} =~ /.+::(.+)/;
+    return if $meth =~ /\Aprepare\z/;
+    $log->tracef("SQL result (%s): %s", $meth, $args->{result});
+}
 
 sub import {
     my $class = shift;
@@ -36,21 +49,26 @@ sub import {
             postcall_logger => \&_postcall_logger,
             filter_methods => sub {
                 my $meth = shift;
-                return unless $meth =~
+                return 1 if $log_query && $meth =~
                     /\A(
-                         DBI::db::(prepare|do)
+                         DBI::db::(prepare|do|select.+)
                      )\z/x;
-                1;
+                return 1 if $log_result && $meth =~
+                    /\A(
+                         DBI::db::(do|select.+) |
+                         DBI::st::(fetch.+)
+                     )\z/x;
+                0;
             },
         );
     };
 
     # DBI is used here to trigger loading of DBI::db
-    $doit->("DBI::db");
+    $doit->("DBI", "DBI::db", "DBI::st");
 }
 
 1;
-# ABSTRACT: Log DBI queries
+# ABSTRACT: Log DBI queries (and results)
 
 __END__
 
@@ -60,34 +78,48 @@ __END__
 
 =head1 NAME
 
-Log::Any::DBI::Query - Log DBI queries
+Log::Any::DBI::Query - Log DBI queries (and results)
 
 =head1 VERSION
 
-This document describes version 0.02 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2015-08-17.
+This document describes version 0.03 of Log::Any::DBI::Query (from Perl distribution Log-Any-DBI-Query), released on 2016-01-23.
 
 =head1 SYNOPSIS
 
  use DBI;
  use Log::Any::DBI::Query;
 
- # now SQL queries passed to prepare()'s and do()'s will be logged
+ # now SQL queries will be logged
  my $dbh = DBI->connect("dbi:...", $user, $pass);
  $dbh->do("INSERT INTO table VALUES (...)");
 
 From command-line:
 
- % perl -MLog::Any::Adapter::ScreenColordLevel -MLog::Any::DBI::Query your-dbi-app.pl
+ % TRACE=1 perl -MLog::Any::Adapter::Screen -MLog::Any::DBI::Query your-dbi-app.pl
+
+To also log SQL results:
+
+ % TRACE=1 LOG_SQL_RESULT=1 \
+     perl -MLog::Any::Adapter::Screen -MLog::Any::DBI::Query your-dbi-app.pl
+
+Sample log output:
+
+ SQL query: {{INSERT INTO table VALUES (...)}
 
 =head1 DESCRIPTION
 
-This is a simple module you can do to log SQL statements/queries for your
-L<DBI>-based applications.
+This is a simple module you can do to log SQL queries for your L<DBI>-based
+applications.
 
-=head1 SEE ALSO
+For queries, it logs calls to C<prepare()>, C<do()>, C<select*>.
 
-L<Log::Any::For::DBI>, which logs calls to C<prepare()>, C<do()>, as well as
-other DBI methods.
+For results, it logs calls to C<do()>, C<select*>, C<fetch*>.
+
+=head1 ENVIRONMENT
+
+=head2 LOG_SQL_QUERY (bool, default 1)
+
+=head2 LOG_SQL_RESULT (bool, default 1)
 
 =head1 HOMEPAGE
 
@@ -105,13 +137,19 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Log::Any::DBI::QueryResult>
+
+L<Log::Any::For::DBI> which logs more methods, including C<connect()>, etc..
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
